Commit 92e5ee9d66e925fb9d02450efed0cf258af94eea

Kano 2013-05-16T19:41:53

fix duplicate name

diff --git a/usbutils.c b/usbutils.c
index b5981f7..f010960 100644
--- a/usbutils.c
+++ b/usbutils.c
@@ -198,7 +198,7 @@ static struct usb_find_devices find_dev[] = {
 		.eps = amu_eps },
 	{
 		.drv = DRV_ICARUS,
-		.name = "BAL",
+		.name = "BLT",
 		.idVendor = 0x0403,
 		.idProduct = 0x6001,
 		.iProduct = "FT232R USB UART",
@@ -208,7 +208,7 @@ static struct usb_find_devices find_dev[] = {
 		.timeout = ICARUS_TIMEOUT_MS,
 		.epcount = ARRAY_SIZE(llt_eps),
 		.eps = llt_eps },
 	// For any that don't match the above "BAL"
 	{
 		.drv = DRV_ICARUS,
 		.name = "LLT",
@@ -208,7 +208,7 @@ static struct usb_find_devices find_dev[] = {
 		.epcount = ARRAY_SIZE(llt_eps),
 		.eps = llt_eps },
-	// For any that don't match the above "BAL"
+	// For any that don't match the above "BLT"
 	{
 		.drv = DRV_ICARUS,